.. testsetup:: *

   from pwnlib.term.readline import *
   import io

:mod:`pwnlib.term.readline` --- Terminal nice readline
======================================================

.. automodule:: pwnlib.term.readline
   :members:
